@@ -1,19 +1,16 @@
 #' Compute results to a CSV file
 #'
-#' For a duckplyr frame, this function executes the query
-#' and stores the results in a CSV file,
-#' without converting it to an R data frame.
+#' This is a generic function that executes a query
+#' and stores the results in a CSV file.
+#' For a duckplyr frame, the materialization occurs outside of R.
 #' The result is a duckplyr frame that can be used with subsequent dplyr verbs.
-#' This function can also be used as a CSV writer for regular data frames.
 #'
 #' @inheritParams rlang::args_dots_empty
-#' @inheritParams compute.duckplyr_df
-#' @inheritParams compute_parquet
-#' @param options A list of additional options to pass to create the storage format,
-#'   see <https://duckdb.org/docs/sql/statements/copy.html#csv-options>
-#'   for details.
+#' @param x A data frame or lazy data frame.
+#' @param path The path of the CSV file to create.
+#' @param ... Additional arguments passed to methods.
 #'
-#' @return A duckplyr frame.
+#' @return A data frame (the class may vary based on the input).
 #'
 #' @export
 #' @examples
@@ -24,7 +21,24 @@
 #' df <- compute_csv(df, path)
 #' readLines(path)
 #' @seealso [compute_parquet()], [compute.duckplyr_df()], [dplyr::collect()]
-compute_csv <- function(x, path, ..., prudence = NULL, options = NULL) {
+compute_csv <- function(x, path, ...) {
+  UseMethod("compute_csv")
+}
+
+#' @inheritParams compute.duckplyr_df
+#' @param options A list of additional options to pass to create the storage format,
+#'   see <https://duckdb.org/docs/sql/statements/copy.html#csv-options>
+#'   for details.
+#'
+#' @rdname compute_csv
+#' @export
+compute_csv.duckplyr_df <- function(
+  x,
+  path,
+  ...,
+  prudence = NULL,
+  options = NULL
+) {
   check_dots_empty()
 
   if (is.null(options)) {
@@ -44,5 +58,20 @@ compute_csv <- function(x, path, ..., prudence = NULL, options = NULL) {
     path <- file.path(path, "**", "**.csv")
   }
 
-  read_csv_duckdb(path, prudence = prudence)
+  # Filter out write-only options before reading
+  read_options <- options[setdiff(names(options), "partition_by")]
+  read_csv_duckdb(path, prudence = prudence, options = read_options)
+}
+
+#' @rdname compute_csv
+#' @export
+compute_csv.data.frame <- function(
+  x,
+  path,
+  ...,
+  prudence = NULL,
+  options = NULL
+) {
+  x <- as_duckdb_tibble(x)
+  compute_csv.duckplyr_df(x, path, ..., prudence = prudence, options = options)
 }
