@@ -10,16 +10,29 @@
 #' @param ... Additional options used by user defined constructors through the `opts` object
 #' @return An object of class <constructive_options/constructive_options_relational_relexpr_constant>
 #' @noRd
-opts_relational_relexpr_constant <- function(constructor = c("relexpr_constant", "next"), ...) {
-  constructive::.cstr_options("relational_relexpr_constant", constructor = constructor[[1]], ...)
+opts_relational_relexpr_constant <- function(
+  constructor = c("relexpr_constant", "next"),
+  ...
+) {
+  constructive::.cstr_options(
+    "relational_relexpr_constant",
+    constructor = constructor[[1]],
+    ...
+  )
 }
 
 .cstr_construct.relational_relexpr_constant <- function(x, ...) {
-  opts <- list(...)$opts$relational_relexpr_constant %||% opts_relational_relexpr_constant()
-  if (is_corrupted_relational_relexpr_constant(x) || opts$constructor == "next") {
+  opts <- list(...)$opts$relational_relexpr_constant %||%
+    opts_relational_relexpr_constant()
+  if (
+    is_corrupted_relational_relexpr_constant(x) || opts$constructor == "next"
+  ) {
     return(NextMethod())
   }
-  UseMethod(".cstr_construct.relational_relexpr_constant", structure(NA, class = opts$constructor))
+  UseMethod(
+    ".cstr_construct.relational_relexpr_constant",
+    structure(NA, class = opts$constructor)
+  )
 }
 
 is_corrupted_relational_relexpr_constant <- function(x) {
@@ -28,7 +41,10 @@ is_corrupted_relational_relexpr_constant <- function(x) {
 
 #' @export
 #' @method .cstr_construct.relational_relexpr_constant relexpr_constant
-.cstr_construct.relational_relexpr_constant.relexpr_constant <- function(x, ...) {
+.cstr_construct.relational_relexpr_constant.relexpr_constant <- function(
+  x,
+  ...
+) {
   # opts <- list(...)$opts$relational_relexpr_constant %||% opts_relational_relexpr_constant()
   args <- compact(list(
     x$val,
@@ -36,11 +52,16 @@ is_corrupted_relational_relexpr_constant <- function(x) {
   ))
   code <- constructive::.cstr_apply(args, fun = "relexpr_constant", ...)
   constructive::.cstr_repair_attributes(
-    x, code, ...,
+    x,
+    code,
+    ...,
     idiomatic_class = c("relational_relexpr_constant", "relational_relexpr")
   )
 }
 
 on_load({
-  vctrs::s3_register("constructive::.cstr_construct", "relational_relexpr_constant")
+  vctrs::s3_register(
+    "constructive::.cstr_construct",
+    "relational_relexpr_constant"
+  )
 })
