@@ -10,23 +10,36 @@
 #' @param ... Additional options used by user defined constructors through the `opts` object
 #' @return An object of class <constructive_options/constructive_options_relational_relexpr_function>
 #' @noRd
-opts_relational_relexpr_function <- function(constructor = c("relexpr_function", "next"), ...) {
+opts_relational_relexpr_function <- function(
+  constructor = c("relexpr_function", "next"),
+  ...
+) {
   # What's forwarded through `...`will be accessible through the `opts`
   # object in the methods.
   # You might add arguments to the function, to document those options,
   # don't forget to forward them below as well
-  constructive::.cstr_options("relational_relexpr_function", constructor = constructor[[1]], ...)
+  constructive::.cstr_options(
+    "relational_relexpr_function",
+    constructor = constructor[[1]],
+    ...
+  )
 }
 
 .cstr_construct.relational_relexpr_function <- function(x, ...) {
   # There is probably no need for you to modify this function at all
-  opts <- list(...)$opts$relational_relexpr_function %||% opts_relational_relexpr_function()
-  if (is_corrupted_relational_relexpr_function(x) || opts$constructor == "next") {
+  opts <- list(...)$opts$relational_relexpr_function %||%
+    opts_relational_relexpr_function()
+  if (
+    is_corrupted_relational_relexpr_function(x) || opts$constructor == "next"
+  ) {
     return(NextMethod())
   }
   # This odd looking code dispatches to a method based on the name of
   # the constructor rather than the class
-  UseMethod(".cstr_construct.relational_relexpr_function", structure(NA, class = opts$constructor))
+  UseMethod(
+    ".cstr_construct.relational_relexpr_function",
+    structure(NA, class = opts$constructor)
+  )
 }
 
 is_corrupted_relational_relexpr_function <- function(x) {
@@ -37,16 +50,22 @@ is_corrupted_relational_relexpr_function <- function(x) {
 
 #' @export
 #' @method .cstr_construct.relational_relexpr_function relexpr_function
-.cstr_construct.relational_relexpr_function.relexpr_function <- function(x, ...) {
+.cstr_construct.relational_relexpr_function.relexpr_function <- function(
+  x,
+  ...
+) {
   # If needed, fetch additional options fed through opts_relational_relexpr_function()
   # opts <- list(...)$opts$relational_relexpr_function %||% opts_relational_relexpr_function()
 
   # Instead of the call below we need to fetch the args of the constructor in `x`.
-  args <- Filter(function(.x) !is.null(.x), list(
-    x$name,
-    x$args,
-    alias = x$alias
-  ))
+  args <- Filter(
+    function(.x) !is.null(.x),
+    list(
+      x$name,
+      x$args,
+      alias = x$alias
+    )
+  )
 
   # This creates a call relexpr_function(...) where ... is the constructed code
   # of the arguments stored in `args`
@@ -57,7 +76,9 @@ is_corrupted_relational_relexpr_function <- function(x) {
   # constructive::.cstr_repair_attributes() makes sure that attributes that are not built
   # by the idiomatic constructor are generated
   constructive::.cstr_repair_attributes(
-    x, code, ...,
+    x,
+    code,
+    ...,
     # attributes built by the constructor
     # ignore =,
 
@@ -67,5 +88,8 @@ is_corrupted_relational_relexpr_function <- function(x) {
 }
 
 on_load({
-  vctrs::s3_register("constructive::.cstr_construct", "relational_relexpr_function")
+  vctrs::s3_register(
+    "constructive::.cstr_construct",
+    "relational_relexpr_function"
+  )
 })
