@@ -3,7 +3,8 @@
 head.duckplyr_df <- function(x, n = 6L, ...) {
   stopifnot(is_integerish(n))
 
-  duckplyr_error <- rel_try(list(name = "head", x = x, args = try_list(n = n)),
+  duckplyr_error <- rel_try(
+    list(name = "head", x = x, args = try_list(n = n)),
     #' @section Fallbacks:
     #' There is no DuckDB translation in `head.duckplyr_df()`
     #' - with a negative `n`.
