@@ -30,13 +30,29 @@
 #' df <- read_csv_duckdb(path, prudence = "lavish")
 #' df$a
 #'
-#' # Specify column types
+#' # Specify column types positionally
 #' read_csv_duckdb(
 #'   path,
 #'   options = list(delim = ",", types = list(c("DOUBLE", "VARCHAR")))
 #' )
-read_csv_duckdb <- function(path, ..., prudence = c("thrifty", "lavish", "stingy"), options = list()) {
+#'
+#' # Specify column types by name
+#' read_csv_duckdb(
+#'   path,
+#'   options = list(types = list(c(a = "DOUBLE", b = "VARCHAR")))
+#' )
+read_csv_duckdb <- function(
+  path,
+  ...,
+  prudence = c("thrifty", "lavish", "stingy"),
+  options = list()
+) {
   check_dots_empty()
 
-  read_file_duckdb(path, "read_csv_auto", prudence = prudence, options = options)
+  read_file_duckdb(
+    path,
+    "read_csv_auto",
+    prudence = prudence,
+    options = options
+  )
 }
