@@ -6,14 +6,32 @@ TPCH_NA_MATCHES <- "never"
 #' @autoglobal
 tpch_01 <- function() {
   lineitem %>%
-    select_opt(l_shipdate, l_returnflag, l_linestatus, l_quantity, l_extendedprice, l_discount, l_tax) %>%
+    select_opt(
+      l_shipdate,
+      l_returnflag,
+      l_linestatus,
+      l_quantity,
+      l_extendedprice,
+      l_discount,
+      l_tax
+    ) %>%
     filter(l_shipdate <= !!as.Date("1998-09-02")) %>%
-    select_opt(l_returnflag, l_linestatus, l_quantity, l_extendedprice, l_discount, l_tax) %>%
+    select_opt(
+      l_returnflag,
+      l_linestatus,
+      l_quantity,
+      l_extendedprice,
+      l_discount,
+      l_tax
+    ) %>%
     summarise(
       sum_qty = sum(na.rm = TRUE, l_quantity),
       sum_base_price = sum(na.rm = TRUE, l_extendedprice),
       sum_disc_price = sum(na.rm = TRUE, l_extendedprice * (1 - l_discount)),
-      sum_charge = sum(na.rm = TRUE, l_extendedprice * (1 - l_discount) * (1 + l_tax)),
+      sum_charge = sum(
+        na.rm = TRUE,
+        l_extendedprice * (1 - l_discount) * (1 + l_tax)
+      ),
       avg_qty = mean(l_quantity),
       avg_price = mean(l_extendedprice),
       avg_disc = mean(l_discount),
@@ -32,20 +50,35 @@ tpch_02 <- function() {
     filter(p_size == 15, grepl("BRASS$", p_type)) %>%
     select_opt(p_partkey, p_mfgr)
 
-  psp <- inner_join(na_matches = TPCH_NA_MATCHES, p, ps, by = c("p_partkey" = "ps_partkey"))
+  psp <- inner_join(
+    na_matches = TPCH_NA_MATCHES,
+    p,
+    ps,
+    by = c("p_partkey" = "ps_partkey")
+  )
 
   sp <- supplier %>%
     select_opt(
-      s_suppkey, s_nationkey, s_acctbal, s_name,
-      s_address, s_phone, s_comment
+      s_suppkey,
+      s_nationkey,
+      s_acctbal,
+      s_name,
+      s_address,
+      s_phone,
+      s_comment
     )
 
-  psps <- inner_join(psp, sp,
-    by = c("ps_suppkey" = "s_suppkey")
-  ) %>%
+  psps <- inner_join(psp, sp, by = c("ps_suppkey" = "s_suppkey")) %>%
     select_opt(
-      p_partkey, ps_supplycost, p_mfgr, s_nationkey,
-      s_acctbal, s_name, s_address, s_phone, s_comment
+      p_partkey,
+      ps_supplycost,
+      p_mfgr,
+      s_nationkey,
+      s_acctbal,
+      s_name,
+      s_address,
+      s_phone,
+      s_comment
     )
 
   nr <- inner_join(
@@ -57,14 +90,23 @@ tpch_02 <- function() {
 
   pspsnr <- inner_join(psps, nr, by = c("s_nationkey" = "n_nationkey")) %>%
     select_opt(
-      p_partkey, ps_supplycost, p_mfgr, n_name, s_acctbal,
-      s_name, s_address, s_phone, s_comment
+      p_partkey,
+      ps_supplycost,
+      p_mfgr,
+      n_name,
+      s_acctbal,
+      s_name,
+      s_address,
+      s_phone,
+      s_comment
     )
 
   aggr <- pspsnr %>%
     summarise(min_ps_supplycost = min(ps_supplycost), .by = p_partkey)
 
-  sj <- inner_join(pspsnr, aggr,
+  sj <- inner_join(
+    pspsnr,
+    aggr,
     by = c(
       "p_partkey" = "p_partkey",
       "ps_supplycost" = "min_ps_supplycost"
@@ -73,8 +115,14 @@ tpch_02 <- function() {
 
   res <- sj %>%
     select(
-      s_acctbal, s_name, n_name, p_partkey, p_mfgr,
-      s_address, s_phone, s_comment
+      s_acctbal,
+      s_name,
+      n_name,
+      p_partkey,
+      p_mfgr,
+      s_address,
+      s_phone,
+      s_comment
     ) %>%
     arrange(desc(s_acctbal), n_name, s_name, p_partkey) %>%
     slice_head(n = 100)
@@ -106,7 +154,10 @@ tpch_03 <- function() {
 
   aggr <- loc %>%
     mutate(volume = l_extendedprice * (1 - l_discount)) %>%
-    summarise(revenue = sum(na.rm = TRUE, volume), .by = c(l_orderkey, o_orderdate, o_shippriority)) %>%
+    summarise(
+      revenue = sum(na.rm = TRUE, volume),
+      .by = c(l_orderkey, o_orderdate, o_shippriority)
+    ) %>%
     select(l_orderkey, revenue, o_orderdate, o_shippriority) %>%
     arrange(desc(revenue), o_orderdate) %>%
     slice_head(n = 10)
@@ -122,11 +173,19 @@ tpch_04 <- function() {
 
   o <- orders %>%
     select_opt(o_orderkey, o_orderdate, o_orderpriority) %>%
-    filter(o_orderdate >= !!as.Date("1993-07-01"), o_orderdate < !!as.Date("1993-10-01")) %>%
+    filter(
+      o_orderdate >= !!as.Date("1993-07-01"),
+      o_orderdate < !!as.Date("1993-10-01")
+    ) %>%
     select(o_orderkey, o_orderpriority)
 
   # distinct after join, tested and indeed faster
-  lo <- inner_join(na_matches = TPCH_NA_MATCHES, l, o, by = c("l_orderkey" = "o_orderkey")) %>%
+  lo <- inner_join(
+    na_matches = TPCH_NA_MATCHES,
+    l,
+    o,
+    by = c("l_orderkey" = "o_orderkey")
+  ) %>%
     distinct() %>%
     select_opt(o_orderpriority)
 
@@ -168,17 +227,24 @@ tpch_05 <- function() {
 
   o <- orders %>%
     select_opt(o_orderdate, o_orderkey, o_custkey) %>%
-    filter(o_orderdate >= !!as.Date("1994-01-01"), o_orderdate < !!as.Date("1995-01-01")) %>%
+    filter(
+      o_orderdate >= !!as.Date("1994-01-01"),
+      o_orderdate < !!as.Date("1995-01-01")
+    ) %>%
     select_opt(o_orderkey, o_custkey)
 
   oc <- inner_join(
-    na_matches = TPCH_NA_MATCHES, o, customer %>% select_opt(c_custkey, c_nationkey),
+    na_matches = TPCH_NA_MATCHES,
+    o,
+    customer %>% select_opt(c_custkey, c_nationkey),
     by = c("o_custkey" = "c_custkey")
   ) %>%
     select_opt(o_orderkey, c_nationkey)
 
   lsnroc <- inner_join(
-    na_matches = TPCH_NA_MATCHES, lsnr, oc,
+    na_matches = TPCH_NA_MATCHES,
+    lsnr,
+    oc,
     by = c("l_orderkey" = "o_orderkey", "s_nationkey" = "c_nationkey")
   ) %>%
     select_opt(l_extendedprice, l_discount, n_name)
@@ -244,18 +310,34 @@ tpch_07 <- function() {
   cnol <- inner_join(
     na_matches = TPCH_NA_MATCHES,
     lineitem %>%
-      select_opt(l_orderkey, l_suppkey, l_shipdate, l_extendedprice, l_discount) %>%
-      filter(l_shipdate >= !!as.Date("1995-01-01"), l_shipdate <= !!as.Date("1996-12-31")),
+      select_opt(
+        l_orderkey,
+        l_suppkey,
+        l_shipdate,
+        l_extendedprice,
+        l_discount
+      ) %>%
+      filter(
+        l_shipdate >= !!as.Date("1995-01-01"),
+        l_shipdate <= !!as.Date("1996-12-31")
+      ),
     cno,
     by = c("l_orderkey" = "o_orderkey")
   ) %>%
     select_opt(l_suppkey, l_shipdate, l_extendedprice, l_discount, n2_name)
 
-  all <- inner_join(na_matches = TPCH_NA_MATCHES, cnol, sn, by = c("l_suppkey" = "s_suppkey"))
+  all <- inner_join(
+    na_matches = TPCH_NA_MATCHES,
+    cnol,
+    sn,
+    by = c("l_suppkey" = "s_suppkey")
+  )
 
   aggr <- all %>%
-    filter((n1_name == "FRANCE" & n2_name == "GERMANY") |
-      (n1_name == "GERMANY" & n2_name == "FRANCE")) %>%
+    filter(
+      (n1_name == "FRANCE" & n2_name == "GERMANY") |
+        (n1_name == "GERMANY" & n2_name == "FRANCE")
+    ) %>%
     mutate(
       supp_nation = n1_name,
       cust_nation = n2_name,
@@ -263,7 +345,10 @@ tpch_07 <- function() {
       volume = l_extendedprice * (1 - l_discount)
     ) %>%
     select_opt(supp_nation, cust_nation, l_year, volume) %>%
-    summarise(revenue = sum(na.rm = TRUE, volume), .by = c(supp_nation, cust_nation, l_year)) %>%
+    summarise(
+      revenue = sum(na.rm = TRUE, volume),
+      .by = c(supp_nation, cust_nation, l_year)
+    ) %>%
     arrange(supp_nation, cust_nation, l_year)
 
   aggr
@@ -296,7 +381,10 @@ tpch_08 <- function() {
     na_matches = TPCH_NA_MATCHES,
     orders %>%
       select_opt(o_orderkey, o_custkey, o_orderdate) %>%
-      filter(o_orderdate >= !!as.Date("1995-01-01"), o_orderdate <= !!as.Date("1996-12-31")),
+      filter(
+        o_orderdate >= !!as.Date("1995-01-01"),
+        o_orderdate <= !!as.Date("1996-12-31")
+      ),
     cnr,
     by = c("o_custkey" = "c_custkey")
   ) %>%
@@ -312,7 +400,8 @@ tpch_08 <- function() {
     select_opt(l_partkey, l_suppkey, l_extendedprice, l_discount, o_orderdate)
 
   locnrp <- inner_join(
-    na_matches = TPCH_NA_MATCHES, locnr,
+    na_matches = TPCH_NA_MATCHES,
+    locnr,
     part %>%
       select_opt(p_partkey, p_type) %>%
       filter(p_type == "ECONOMY ANODIZED STEEL") %>%
@@ -322,7 +411,8 @@ tpch_08 <- function() {
     select_opt(l_suppkey, l_extendedprice, l_discount, o_orderdate)
 
   locnrps <- inner_join(
-    na_matches = TPCH_NA_MATCHES, locnrp,
+    na_matches = TPCH_NA_MATCHES,
+    locnrp,
     supplier %>%
       select_opt(s_suppkey, s_nationkey),
     by = c("l_suppkey" = "s_suppkey")
@@ -330,7 +420,8 @@ tpch_08 <- function() {
     select_opt(l_extendedprice, l_discount, o_orderdate, s_nationkey)
 
   all <- inner_join(
-    na_matches = TPCH_NA_MATCHES, locnrps,
+    na_matches = TPCH_NA_MATCHES,
+    locnrps,
     nation %>%
       select(n2_nationkey = n_nationkey, n2_name = n_name),
     by = c("s_nationkey" = "n2_nationkey")
@@ -339,13 +430,14 @@ tpch_08 <- function() {
 
   aggr <- all %>%
     mutate(
-      o_year =  as.integer(strftime(o_orderdate, "%Y")),
+      o_year = as.integer(strftime(o_orderdate, "%Y")),
       volume = l_extendedprice * (1 - l_discount),
       nation = n2_name
     ) %>%
     select_opt(o_year, volume, nation) %>%
     summarise(
-      mkt_share = sum(na.rm = TRUE, if_else(nation == "BRAZIL", volume, 0)) / sum(na.rm = TRUE, volume),
+      mkt_share = sum(na.rm = TRUE, if_else(nation == "BRAZIL", volume, 0)) /
+        sum(na.rm = TRUE, volume),
       .by = o_year
     ) %>%
     arrange(o_year)
@@ -377,16 +469,35 @@ tpch_09 <- function() {
   ) %>%
     select_opt(s_suppkey, n_name)
 
-  pspsn <- inner_join(na_matches = TPCH_NA_MATCHES, psp, sn, by = c("ps_suppkey" = "s_suppkey"))
+  pspsn <- inner_join(
+    na_matches = TPCH_NA_MATCHES,
+    psp,
+    sn,
+    by = c("ps_suppkey" = "s_suppkey")
+  )
 
   lpspsn <- inner_join(
     na_matches = TPCH_NA_MATCHES,
     lineitem %>%
-      select_opt(l_suppkey, l_partkey, l_orderkey, l_extendedprice, l_discount, l_quantity),
+      select_opt(
+        l_suppkey,
+        l_partkey,
+        l_orderkey,
+        l_extendedprice,
+        l_discount,
+        l_quantity
+      ),
     pspsn,
     by = c("l_suppkey" = "ps_suppkey", "l_partkey" = "ps_partkey")
   ) %>%
-    select_opt(l_orderkey, l_extendedprice, l_discount, l_quantity, ps_supplycost, n_name)
+    select_opt(
+      l_orderkey,
+      l_extendedprice,
+      l_discount,
+      l_quantity,
+      ps_supplycost,
+      n_name
+    )
 
   all <- inner_join(
     na_matches = TPCH_NA_MATCHES,
@@ -395,7 +506,14 @@ tpch_09 <- function() {
     lpspsn,
     by = c("o_orderkey" = "l_orderkey")
   ) %>%
-    select_opt(l_extendedprice, l_discount, l_quantity, ps_supplycost, n_name, o_orderdate)
+    select_opt(
+      l_extendedprice,
+      l_discount,
+      l_quantity,
+      ps_supplycost,
+      n_name,
+      o_orderdate
+    )
 
   aggr <- all %>%
     mutate(
@@ -404,7 +522,10 @@ tpch_09 <- function() {
       amount = l_extendedprice * (1 - l_discount) - ps_supplycost * l_quantity
     ) %>%
     select_opt(nation, o_year, amount) %>%
-    summarise(sum_profit = sum(na.rm = TRUE, amount), .by = c(nation, o_year)) %>%
+    summarise(
+      sum_profit = sum(na.rm = TRUE, amount),
+      .by = c(nation, o_year)
+    ) %>%
     arrange(nation, desc(o_year))
 
   aggr
@@ -419,11 +540,16 @@ tpch_10 <- function() {
 
   o <- orders %>%
     select_opt(o_orderkey, o_custkey, o_orderdate) %>%
-    filter(o_orderdate >= !!as.Date("1993-10-01"), o_orderdate < !!as.Date("1994-01-01")) %>%
+    filter(
+      o_orderdate >= !!as.Date("1993-10-01"),
+      o_orderdate < !!as.Date("1994-01-01")
+    ) %>%
     select_opt(o_orderkey, o_custkey)
 
   lo <- inner_join(
-    na_matches = TPCH_NA_MATCHES, l, o,
+    na_matches = TPCH_NA_MATCHES,
+    l,
+    o,
     by = c("l_orderkey" = "o_orderkey")
   ) %>%
     select_opt(l_extendedprice, l_discount, o_custkey)
@@ -435,19 +561,40 @@ tpch_10 <- function() {
     summarise(revenue = sum(na.rm = TRUE, volume), .by = o_custkey)
 
   c <- customer %>%
-    select_opt(c_custkey, c_nationkey, c_name, c_acctbal, c_phone, c_address, c_comment)
+    select_opt(
+      c_custkey,
+      c_nationkey,
+      c_name,
+      c_acctbal,
+      c_phone,
+      c_address,
+      c_comment
+    )
 
-  loc <- inner_join(na_matches = TPCH_NA_MATCHES, c, lo_aggr, by = c("c_custkey" = "o_custkey"))
+  loc <- inner_join(
+    na_matches = TPCH_NA_MATCHES,
+    c,
+    lo_aggr,
+    by = c("c_custkey" = "o_custkey")
+  )
 
   locn <- inner_join(
-    na_matches = TPCH_NA_MATCHES, loc, nation %>% select_opt(n_nationkey, n_name),
+    na_matches = TPCH_NA_MATCHES,
+    loc,
+    nation %>% select_opt(n_nationkey, n_name),
     by = c("c_nationkey" = "n_nationkey")
   )
 
   res <- locn %>%
     select(
-      c_custkey, c_name, revenue, c_acctbal, n_name,
-      c_address, c_phone, c_comment
+      c_custkey,
+      c_name,
+      revenue,
+      c_acctbal,
+      n_name,
+      c_address,
+      c_phone,
+      c_comment
     ) %>%
     arrange(desc(revenue)) %>%
     slice_head(n = 20)
