@@ -1,8 +1,14 @@
 start <- Sys.time()
 
-withr::local_envvar(DUCKPLYR_FALLBACK_COLLECT = 0, .local_envir = testthat::teardown_env())
+withr::local_envvar(
+  DUCKPLYR_FALLBACK_COLLECT = 0,
+  .local_envir = testthat::teardown_env()
+)
 
-withr::local_envvar(DUCKPLYR_OUTPUT_ORDER = TRUE, .local_envir = testthat::teardown_env())
+withr::local_envvar(
+  DUCKPLYR_OUTPUT_ORDER = TRUE,
+  .local_envir = testthat::teardown_env()
+)
 
 # withr::local_envvar(DUCKPLYR_TELEMETRY_PREP_TEST = TRUE, .local_envir = testthat::teardown_env())
 
