@@ -6,10 +6,16 @@ test_that("as_duckplyr_tibble() works", {
   local_options(lifecycle_verbosity = "quiet")
 
   expect_s3_class(as_duckplyr_tibble(tibble(a = 1)), "duckplyr_df")
-  expect_equal(class(as_duckplyr_tibble(tibble(a = 1))), c("duckplyr_df", class(tibble())))
+  expect_equal(
+    class(as_duckplyr_tibble(tibble(a = 1))),
+    c("duckplyr_df", class(tibble()))
+  )
 
   expect_s3_class(as_duckplyr_tibble(data.frame(a = 1)), "duckplyr_df")
-  expect_equal(class(as_duckplyr_tibble(data.frame(a = 1))), c("duckplyr_df", class(tibble())))
+  expect_equal(
+    class(as_duckplyr_tibble(data.frame(a = 1))),
+    c("duckplyr_df", class(tibble()))
+  )
 })
 
 test_that("as_duckplyr_df() and special df", {
