@@ -4,7 +4,13 @@ test_that("can construct expressions", {
   expect_snapshot({
     relexpr_reference("column")
     relexpr_constant(42)
-    relexpr_function("+", list(relexpr_reference("column"), relexpr_constant(42, alias = "fortytwo")))
+    relexpr_function(
+      "+",
+      list(
+        relexpr_reference("column"),
+        relexpr_constant(42, alias = "fortytwo")
+      )
+    )
   })
 })
 
